==> haskell-wai-conduit-3.0.0.4-65-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-conduit
version: 3.0.0.4
id: wai-conduit-3.0.0.4-2Lms5HFdSnyEK2Dr6ybeFP
key: wai-conduit-3.0.0.4-2Lms5HFdSnyEK2Dr6ybeFP
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/yesodweb/wai
synopsis: conduit wrappers for WAI
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-conduit>.
category: Web, Conduit
abi: 3312ff4653c193ced6871de8803a4b57
exposed: True
exposed-modules:
    Network.Wai.Conduit
import-dirs: /usr/lib/ghc-8.4.3/site-local/wai-conduit-3.0.0.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/wai-conduit-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/wai-conduit-3.0.0.4
hs-libraries: HSwai-conduit-3.0.0.4-2Lms5HFdSnyEK2Dr6ybeFP
depends:
    base-4.11.1.0 wai-3.2.1.2-LYrgj5pDFEpLGOS1bmSP2u
    conduit-1.3.0.3-2kQyPNl7LmHLxxI2wSVWau transformers-0.5.5.0
    bytestring-0.10.8.2 http-types-0.12.1-C6lpBNl8s0n56pfgsv3YNb
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             wai-3.2.1.2-LYrgj5pDFEpLGOS1bmSP2u=d9fba6511abb80273dc6e619fc5c09ff
             conduit-1.3.0.3-2kQyPNl7LmHLxxI2wSVWau=165b50aef4a213b491f6528fa1a2f4d1
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             http-types-0.12.1-C6lpBNl8s0n56pfgsv3YNb=976aaa70f9b7212c24b31f28f22b380a
haddock-interfaces: /usr/share/doc/haskell-wai-conduit/html/wai-conduit.haddock
haddock-html: /usr/share/doc/haskell-wai-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-conduit-3.0.0.4-66-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-wai-conduit.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wai-conduit
version: 3.0.0.4
id: wai-conduit-3.0.0.4-KRbHCn54zcZBI8XJ9zeegi
key: wai-conduit-3.0.0.4-KRbHCn54zcZBI8XJ9zeegi
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/yesodweb/wai
synopsis: conduit wrappers for WAI
description:
    API docs and the README are available at <http://www.stackage.org/package/wai-conduit>.
category: Web, Conduit
abi: 3b3207b6a02de724d106694823913ec1
exposed: True
exposed-modules:
    Network.Wai.Conduit
import-dirs: /usr/lib/ghc-8.4.3/site-local/wai-conduit-3.0.0.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/wai-conduit-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/wai-conduit-3.0.0.4
hs-libraries: HSwai-conduit-3.0.0.4-KRbHCn54zcZBI8XJ9zeegi
depends:
    base-4.11.1.0 wai-3.2.1.2-LYrgj5pDFEpLGOS1bmSP2u
    conduit-1.3.0.3-7hM2y3vt6zPJrBL0QWA5kl transformers-0.5.5.0
    bytestring-0.10.8.2 http-types-0.12.1-C6lpBNl8s0n56pfgsv3YNb
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             wai-3.2.1.2-LYrgj5pDFEpLGOS1bmSP2u=d9fba6511abb80273dc6e619fc5c09ff
             conduit-1.3.0.3-7hM2y3vt6zPJrBL0QWA5kl=027922e93a267b72b868d4ff5db4d6d0
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             http-types-0.12.1-C6lpBNl8s0n56pfgsv3YNb=976aaa70f9b7212c24b31f28f22b380a
haddock-interfaces: /usr/share/doc/haskell-wai-conduit/html/wai-conduit.haddock
haddock-html: /usr/share/doc/haskell-wai-conduit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
